"""Request Body Schemas for API Tools

DO NOT EDIT THIS MODULE DIRECTLY.

THIS MODULE WAS AUTO-GENERATED AND CONTAINS OpenAPI REQUEST BODY SCHEMAS
FOR TOOLS WITH COMPLEX REQUEST BODIES. ANY CHANGES TO THIS MODULE WILL
BE OVERWRITTEN BY THE TRANSPILER.
"""

from typing import Any

REQUEST_BODY_SCHEMAS: dict[str, Any] = {
    "RETRIEVEHUBSPOTCRMRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPDATEMULTIPLEHUBSPOTAPPOINTMENTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATECRMAPPOINTMENT": '{"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "CREATEBATCHAPPOINTMENTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPSERTHUBSPOTRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "SEARCHAPPOINTMENTS": '{"required": ["after", "filterGroups", "limit", "properties", "sorts"], "type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "ARCHIVEMULTIPLEAPPOINTMENTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATEHUBSPOTOBJECT": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "CREATEBATCHASSOCIATIONSHUBSPOT": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["from", "to", "type"], "type": "object", "properties": {"from": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}, "type": {"type": "string"}}, "example": {"from": {"id": "53628"}, "to": {"id": "12726"}, "type": "contact_to_company"}}}}}',  # noqa: E501
    "BATCHREADASSOCIATIONS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "HUBSPOTBATCHARCHIVEASSOCIATIONS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["from", "to", "type"], "type": "object", "properties": {"from": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}, "type": {"type": "string"}}, "example": {"from": {"id": "53628"}, "to": {"id": "12726"}, "type": "contact_to_company"}}}}}',  # noqa: E501
    "CREATEBATCHOFCALLS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPSERTCALLRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "RETRIEVECALLSBATCH": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPDATEBATCHCALLS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATEHUBSPOTCALL": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "UPDATECALLINFO": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "ARCHIVECALLSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "SEARCHCALLSHUBSPOT": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "ARCHIVECARTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "CREATEBATCHOFCARTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "CREATECARTHUBSPOTCRM": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "RETRIEVECARTRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPSERTCARTRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "UPDATECARTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "SEARCHHUBSPOTCARTS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "UPDATECARTPROPERTIES": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPSERTCOMMERCEPAYMENTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATEBATCHCOMMERCEPAYMENTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPDATECOMMERCEPAYMENT": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "ARCHIVECOMMERCEPAYMENTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATECOMMERCEPAYMENTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "RETRIEVECOMMERCEPAYMENTRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "SEARCHCOMMERCEPAYMENTS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "CREATECOMMERCEPAYMENT": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "UPDATESUBSCRIPTIONBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "ARCHIVESUBSCRIPTIONSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "SEARCHHUBSPOTSUBSCRIPTIONS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "CREATESUBSCRIPTION": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "UPSERTSUBSCRIPTIONSINHUBSPOTCRM": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "RETRIEVESUBSCRIPTIONRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATEBATCHSUBSCRIPTIONS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPDATESUBSCRIPTION": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPDATEMESSAGESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "DELETEBATCHMESSAGES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPSERTCOMMUNICATIONSRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATEHUBSPOTCOMMUNICATION": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "UPDATECOMMUNICATIONDETAILS": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "SEARCHCRMMESSAGES": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "RETRIEVEBATCHCOMMUNICATIONS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATEHUBSPOTMESSAGESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "RETRIEVEBATCHCOMPANIESHUBSPOT": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATECOMPANYHUBSPOT": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "The company property values to set."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "SEARCHCOMPANIESINHUBSPOT": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "UPDATEHUBSPOTCOMPANY": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "The company property values to set."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "CREATEORUPDATECOMPANIES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "UPDATEBATCHOFCOMPANIES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATEBATCHOFCOMPANIES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "DELETECOMPANIESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "BATCHREADCONTACTS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "items": {"type": "string"}}, "idProperty": {"type": "string"}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "items": {"type": "string"}}}}',  # noqa: E501
    "UPDATECONTACTINFORMATION": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "example": {"property_date": "1572480000000", "property_radio": "option_1", "property_number": "17", "property_string": "value", "property_checkbox": "false", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry"}}}, "example": {"properties": {"email": "bcooper@biglytics.net", "phone": "(877) 929-0687", "company": "Biglytics", "website": "biglytics.net", "lastname": "Cooper", "firstname": "Bryan"}, "associations": []}}',  # noqa: E501
    "ARCHIVECONTACTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "CREATEBATCHCONTACTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}}}}',  # noqa: E501
    "UPDATEBATCHCONTACTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATEHUBSPOTCONTACT": '{"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}, "example": {"properties": {"email": "bcooper@biglytics.net", "phone": "(877) 929-0687", "company": "Biglytics", "website": "biglytics.net", "lastname": "Cooper", "firstname": "Bryan"}, "associations": []}}',  # noqa: E501
    "SEARCHCONTACTS": '{"required": ["after", "filterGroups", "limit", "properties", "sorts"], "type": "object", "properties": {"query": {"type": "string"}, "limit": {"type": "integer", "format": "int32"}, "after": {"type": "string"}, "sorts": {"type": "array", "items": {"type": "string"}}, "properties": {"type": "array", "items": {"type": "string"}}, "filterGroups": {"type": "array", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}}',  # noqa: E501
    "UPSERTCONTACTBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATEHUBSPOTCOURSE": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "ARCHIVECOURSESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATEHUBSPOTCOURSE": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "CREATEBATCHOFCOURSES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "BATCHUPSERTRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "HUBSPOTCRMSEARCHOBJECTS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "UPDATECOURSESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "RETRIEVEHUBSPOTRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "BATCHRETRIEVEHUBSPOTRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "MODIFYHUBSPOTOBJECT": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "ARCHIVEHUBSPOTOBJECTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATEHUBSPOTOBJECTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATEHUBSPOTOBJECTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPDATEORCREATEHUBSPOTRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATECRMOBJECT": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "SEARCHHUBSPOTOBJECTS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "UPDATEMULTIPLEDEALS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "SEARCHDEALS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "CREATEORUPDATEHUBSPOTRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "ARCHIVEMULTIPLEDEALS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "RETRIEVECRMRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPDATEHUBSPOTDEAL": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "CREATEMULTIPLEDEALS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "CREATEHUBSPOTDEAL": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "MANAGEDEALSPLITS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "splits"], "type": "object", "properties": {"splits": {"type": "array", "items": {"required": ["ownerId", "percentage"], "type": "object", "properties": {"percentage": {"type": "number"}, "ownerId": {"type": "integer", "format": "int32"}}}}, "id": {"type": "integer", "format": "int32"}}}}}}',  # noqa: E501
    "READBATCHDEALSPLITS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "SEARCHDISCOUNTS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "UPDATEDISCOUNTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "UPDATEDISCOUNTDETAILS": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "CREATEBATCHDISCOUNTSHUBSPOT": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPSERTDISCOUNTRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "ARCHIVEDISCOUNTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "CREATEDISCOUNT": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "RETRIEVEDISCOUNTRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATEBATCHOFEMAILS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "CREATEHUBSPOTEMAIL": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "RETRIEVEEMAILRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATEORUPDATEHUBSPOTEMAILS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "UPDATEEMAILINHUBSPOTCRM": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "ARCHIVEEMAILSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATEBATCHEMAILS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "SEARCHEMAILS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "SEARCHFEEDBACKSUBMISSIONS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "RETRIEVEFEEDBACKRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPDATEFEEDETAILS": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPSERTHUBSPOTFEES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATEFEEINCRM": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "CREATEBATCHFEES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "SEARCHFEESINCRM": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "UPDATEBATCHFEES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "ARCHIVEFEESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "RETRIEVEFEERECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATEGOALTARGETSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "RETRIEVEGOALTARGETS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPDATEGOALTARGET": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "SEARCHGOALTARGETS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "ARCHIVEGOALTARGETSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATEBATCHGOALTARGETS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "UPSERTGOALTARGETS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATEGOALTARGET": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "CREATEBATCHOFINVOICES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "SEARCHINVOICES": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "RETRIEVEINVOICERECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPDATEINVOICEDETAILS": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPDATEINVOICESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATEHUBSPOTINVOICE": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "UPSERTHUBSPOTINVOICES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "ARCHIVEINVOICESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "RETRIEVELEADRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "SEARCHCRMLEADS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "CREATELEADHUBSPOT": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "CREATELEADSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPDATELEADSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "UPDATELEADDETAILS": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "ARCHIVELEADSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "CREATEHUBSPOTLINEITEM": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "UPDATELINEITEM": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPSERTLINEITEMSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATELINEITEMSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPDATELINEITEMSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "SEARCHLINEITEMS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "RETRIEVEBATCHLINEITEMS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "ARCHIVELINEITEMSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "CREATEHUBSPOTLISTING": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "ARCHIVEMULTIPLELISTINGS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATEMULTIPLECRMLISTINGS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "FETCHHUBSPOTRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATEMULTIPLELISTINGS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "CREATEORUPDATEBATCHRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "SEARCHHUBSPOTLISTINGS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "HUBSPOTUPDATELISTING": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "SCHEDULELISTCONVERSION": '{"properties": {}, "oneOf": [{"title": "CONVERSION_DATE", "required": ["conversionType", "day", "month", "year"], "type": "object", "properties": {"month": {"type": "integer", "format": "int32"}, "year": {"type": "integer", "format": "int32"}, "conversionType": {"type": "string", "default": "CONVERSION_DATE", "enum": ["CONVERSION_DATE"]}, "day": {"type": "integer", "format": "int32"}}}, {"title": "INACTIVITY", "required": ["conversionType", "offset", "timeUnit"], "type": "object", "properties": {"offset": {"type": "integer", "format": "int32"}, "conversionType": {"type": "string", "default": "INACTIVITY", "enum": ["INACTIVITY"]}, "timeUnit": {"type": "string", "enum": ["DAY", "WEEK", "MONTH"]}}}]}',  # noqa: E501
    "UPDATEHUBSPOTMEETING": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPDATEMEETINGSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "RETRIEVEMEETINGRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "ARCHIVEMEETINGSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "CREATEHUBSPOTMEETING": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "UPSERTMEETINGS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATEBATCHMEETINGS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "SEARCHHUBSPOTMEETINGS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "SEARCHHUBSPOTNOTES": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "CREATENOTEINHUBSPOT": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "RETRIEVENOTESRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPSERTNOTESHUBSPOT": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "ARCHIVENOTESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "BATCHUPDATENOTES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATEBATCHOFNOTES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPDATEHUBSPOTNOTE": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "SEARCHORDERRECORDS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "RETRIEVEHUBSPOTORDERS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPDATEORDERDETAILS": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPSERTORDERSINHUBSPOT": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATEBATCHORDERS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPDATEHUBSPOTORDERSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATEHUBSPOTORDER": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "ARCHIVEORDERSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATEPARTNERCLIENTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "BATCHREADPARTNERCLIENTS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "SEARCHPARTNERCLIENTS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "UPDATEPARTNERCLIENT": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPDATEPARTNERSERVICE": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "RETRIEVEPARTNERSERVICESRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "SEARCHPARTNERSERVICESHUBSPOT": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "UPDATEPARTNERSERVICESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "READBATCHPAYMENTS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "items": {"type": "string"}}, "idProperty": {"type": "string"}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "items": {"type": "string"}}}}',  # noqa: E501
    "SEARCHHUBSPOTPAYMENTS": '{"required": ["after", "filterGroups", "limit", "properties", "sorts"], "type": "object", "properties": {"query": {"type": "string"}, "limit": {"type": "integer", "format": "int32"}, "after": {"type": "string"}, "sorts": {"type": "array", "items": {"type": "string"}}, "properties": {"type": "array", "items": {"type": "string"}}, "filterGroups": {"type": "array", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}}',  # noqa: E501
    "REPLACEPIPELINEHUBSPOT": '{"required": ["displayOrder", "label", "stages"], "type": "object", "properties": {"displayOrder": {"type": "integer", "description": "The order for displaying this pipeline. If two pipelines have a matching `displayOrder`, they will be sorted alphabetically by label.", "format": "int32"}, "stages": {"type": "array", "description": "Pipeline stage inputs used to create the new or replacement pipeline.", "items": {"required": ["displayOrder", "label"], "type": "object", "properties": {"metadata": {"type": "object", "additionalProperties": {"type": "string"}, "description": "A JSON object containing properties that are not present on all object pipelines.\n\nFor `deals` pipelines, the `probability` field is required (`{ "probability": 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.\n\nFor `tickets` pipelines, the `ticketState` field is optional (`{ "ticketState": "OPEN" }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`."}, "displayOrder": {"type": "integer", "description": "The order for displaying this pipeline stage. If two pipeline stages have a matching `displayOrder`, they will be sorted alphabetically by label.", "format": "int32"}, "label": {"type": "string", "description": "A label used to organize pipeline stages in HubSpot\'s UI. Each pipeline stage\'s label must be unique within that pipeline."}}, "description": "An input used to create or replace a pipeline stage\'s definition.", "example": {"label": "Done", "displayOrder": 1, "metadata": {"ticketState": "CLOSED"}}}}, "label": {"type": "string", "description": "A unique label used to organize pipelines in HubSpot\'s UI"}}, "description": "An input used to create or replace a pipeline\'s definition.", "example": {"label": "My replaced pipeline", "displayOrder": 0, "stages": [{"label": "In Progress", "displayOrder": 0, "metadata": {"ticketState": "OPEN"}}, {"label": "Done", "displayOrder": 1, "metadata": {"ticketState": "CLOSED"}}]}}',  # noqa: E501
    "CREATEPIPELINESTAGE": '{"required": ["displayOrder", "label"], "type": "object", "properties": {"metadata": {"type": "object", "additionalProperties": {"type": "string"}, "description": "A JSON object containing properties that are not present on all object pipelines.\n\nFor `deals` pipelines, the `probability` field is required (`{ "probability": 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.\n\nFor `tickets` pipelines, the `ticketState` field is optional (`{ "ticketState": "OPEN" }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`."}, "displayOrder": {"type": "integer", "description": "The order for displaying this pipeline stage. If two pipeline stages have a matching `displayOrder`, they will be sorted alphabetically by label.", "format": "int32"}, "label": {"type": "string", "description": "A label used to organize pipeline stages in HubSpot\'s UI. Each pipeline stage\'s label must be unique within that pipeline."}}, "description": "An input used to create or replace a pipeline stage\'s definition.", "example": {"label": "Done", "displayOrder": 1, "metadata": {"ticketState": "CLOSED"}}}',  # noqa: E501
    "CREATECRMPIPELINE": '{"required": ["displayOrder", "label", "stages"], "type": "object", "properties": {"displayOrder": {"type": "integer", "description": "The order for displaying this pipeline. If two pipelines have a matching `displayOrder`, they will be sorted alphabetically by label.", "format": "int32"}, "stages": {"type": "array", "description": "Pipeline stage inputs used to create the new or replacement pipeline.", "items": {"required": ["displayOrder", "label"], "type": "object", "properties": {"metadata": {"type": "object", "additionalProperties": {"type": "string"}, "description": "A JSON object containing properties that are not present on all object pipelines.\n\nFor `deals` pipelines, the `probability` field is required (`{ "probability": 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.\n\nFor `tickets` pipelines, the `ticketState` field is optional (`{ "ticketState": "OPEN" }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`."}, "displayOrder": {"type": "integer", "description": "The order for displaying this pipeline stage. If two pipeline stages have a matching `displayOrder`, they will be sorted alphabetically by label.", "format": "int32"}, "label": {"type": "string", "description": "A label used to organize pipeline stages in HubSpot\'s UI. Each pipeline stage\'s label must be unique within that pipeline."}}, "description": "An input used to create or replace a pipeline stage\'s definition.", "example": {"label": "Done", "displayOrder": 1, "metadata": {"ticketState": "CLOSED"}}}}, "label": {"type": "string", "description": "A unique label used to organize pipelines in HubSpot\'s UI"}}, "description": "An input used to create or replace a pipeline\'s definition.", "example": {"label": "My replaced pipeline", "displayOrder": 0, "stages": [{"label": "In Progress", "displayOrder": 0, "metadata": {"ticketState": "OPEN"}}, {"label": "Done", "displayOrder": 1, "metadata": {"ticketState": "CLOSED"}}]}}',  # noqa: E501
    "REPLACEPIPELINESTAGEPROPERTIES": '{"required": ["displayOrder", "label"], "type": "object", "properties": {"metadata": {"type": "object", "additionalProperties": {"type": "string"}, "description": "A JSON object containing properties that are not present on all object pipelines.\n\nFor `deals` pipelines, the `probability` field is required (`{ "probability": 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.\n\nFor `tickets` pipelines, the `ticketState` field is optional (`{ "ticketState": "OPEN" }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`."}, "displayOrder": {"type": "integer", "description": "The order for displaying this pipeline stage. If two pipeline stages have a matching `displayOrder`, they will be sorted alphabetically by label.", "format": "int32"}, "label": {"type": "string", "description": "A label used to organize pipeline stages in HubSpot\'s UI. Each pipeline stage\'s label must be unique within that pipeline."}}, "description": "An input used to create or replace a pipeline stage\'s definition.", "example": {"label": "Done", "displayOrder": 1, "metadata": {"ticketState": "CLOSED"}}}',  # noqa: E501
    "UPDATEPIPELINESTAGE": '{"type": "object", "properties": {"archived": {"type": "boolean", "description": "Whether the pipeline is archived."}, "metadata": {"type": "object", "additionalProperties": {"type": "string"}, "description": "A JSON object containing properties that are not present on all object pipelines.\n\nFor `deals` pipelines, the `probability` field is required (`{ "probability": 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.\n\nFor `tickets` pipelines, the `ticketState` field is optional (`{ "ticketState": "OPEN" }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`."}, "displayOrder": {"type": "integer", "description": "The order for displaying this pipeline stage. If two pipeline stages have a matching `displayOrder`, they will be sorted alphabetically by label.", "format": "int32"}, "label": {"type": "string", "description": "A label used to organize pipeline stages in HubSpot\'s UI. Each pipeline stage\'s label must be unique within that pipeline."}}, "description": "An input used to update some properties on a pipeline definition.", "example": {"label": "Done", "displayOrder": 1, "metadata": {"ticketState": "CLOSED"}}}',  # noqa: E501
    "GETMULTIPLEPOSTALMAILOBJECTS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "ARCHIVEPOSTALMAILBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "CREATEPOSTALMAILOBJECT": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "CREATEPOSTALMAILBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPSERTPOSTALMAILINHUBSPOT": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "UPDATEPOSTALMAILRECORD": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPDATEMULTIPLEPOSTALMAILS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "SEARCHPOSTALMAILHUBSPOT": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "ARCHIVEPRODUCTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "CREATEPRODUCTINHUBSPOT": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "SEARCHHUBSPOTPRODUCTS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "RETRIEVEHUBSPOTPRODUCTRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATEBATCHOFPRODUCTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPSERTHUBSPOTPRODUCTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "UPDATEPRODUCTINFO": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPDATEHUBSPOTPRODUCTSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "ARCHIVECRMPROPERTIES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["name"], "type": "object", "properties": {"name": {"type": "string", "description": "The name of the property to read or modify."}}, "example": {"name": "my_custom_property"}}}}}',  # noqa: E501
    "UPDATEPROPERTYVALUE": '{"type": "object", "properties": {"groupName": {"type": "string", "description": "The name of the property group the property belongs to."}, "hidden": {"type": "boolean", "description": "If true, the property won\'t be visible and can\'t be used in HubSpot."}, "options": {"type": "array", "description": "A list of valid options for the property.", "items": {"required": ["hidden", "label", "value"], "type": "object", "properties": {"hidden": {"type": "boolean", "description": "If true, the option will not be shown in forms, bots, or meeting scheduling pages. Supported for contact, company, ticket, and custom object enumeration properties."}, "displayOrder": {"type": "integer", "description": "Options are shown in order starting with the lowest positive integer value. Values of -1 will cause the option to be displayed after any positive values.", "format": "int32"}, "description": {"type": "string", "description": "A description of the option."}, "label": {"type": "string", "description": "A human-readable option label that will be shown in HubSpot."}, "value": {"type": "string", "description": "The internal value of the option, which must be used when setting the property value through the API."}}, "example": {"description": "Choice number one", "displayOrder": 1, "hidden": false, "label": "Option A", "value": "A"}}}, "displayOrder": {"type": "integer", "description": "Properties are displayed in order starting with the lowest positive integer value. Values of -1 will cause the Property to be displayed after any positive values.", "format": "int32"}, "description": {"type": "string", "description": "A description of the property that will be shown as help text in HubSpot."}, "calculationFormula": {"type": "string", "description": "Represents a formula that is used to compute a calculated property."}, "label": {"type": "string", "description": "A human-readable property label that will be shown in HubSpot."}, "type": {"type": "string", "description": "The data type of the property.", "enum": ["bool", "date", "datetime", "enumeration", "number", "phone_number", "string"]}, "fieldType": {"type": "string", "description": "Controls how the property appears in HubSpot.", "enum": ["booleancheckbox", "calculation_equation", "checkbox", "date", "file", "html", "number", "phonenumber", "radio", "select", "text", "textarea"]}, "formField": {"type": "boolean", "description": "Whether or not the property can be used in a HubSpot form."}}, "example": {"displayOrder": 2, "fieldType": "select", "formField": true, "groupName": "contactinformation", "hidden": false, "label": "My Contact Property", "name": "my_contact_property", "options": [{"description": "Choice number one", "displayOrder": 1, "hidden": false, "label": "Option A", "value": "A"}, {"description": "Choice number two", "displayOrder": 2, "hidden": false, "label": "Option B", "value": "B"}], "type": "enumeration"}}',  # noqa: E501
    "READBATCHPROPERTIES": '{"required": ["archived", "inputs"], "type": "object", "properties": {"archived": {"type": "boolean"}, "inputs": {"type": "array", "items": {"required": ["name"], "type": "object", "properties": {"name": {"type": "string", "description": "The name of the property to read or modify."}}, "example": {"name": "my_custom_property"}}}, "dataSensitivity": {"type": "string", "enum": ["non_sensitive", "sensitive", "highly_sensitive"]}}}',  # noqa: E501
    "CREATEBATCHPROPERTIES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["fieldType", "groupName", "label", "name", "type"], "type": "object", "properties": {"hidden": {"type": "boolean", "description": "If true, the option will not be shown in forms, bots, or meeting scheduling pages. Supported for contact, company, ticket, and custom object enumeration properties."}, "displayOrder": {"type": "integer", "description": "Properties are displayed in order starting with the lowest positive integer value. Values of -1 will cause the property to be displayed after any positive values.", "format": "int32"}, "description": {"type": "string", "description": "A description of the property that will be shown as help text in HubSpot."}, "label": {"type": "string", "description": "A human-readable property label that will be shown in HubSpot."}, "type": {"type": "string", "description": "The data type of the property.", "enum": ["bool", "date", "datetime", "enumeration", "number", "phone_number", "string"]}, "formField": {"type": "boolean", "description": "Whether or not the property can be used in a HubSpot form."}, "dataSensitivity": {"type": "string", "enum": ["non_sensitive", "sensitive", "highly_sensitive"]}, "groupName": {"type": "string", "description": "The name of the property group the property belongs to."}, "referencedObjectType": {"type": "string", "description": "Should be set to \'OWNER\' when \'externalOptions\' is true, which causes the property to dynamically pull option values from the current HubSpot users."}, "name": {"type": "string", "description": "The internal property name, which must be used when referencing the property via the API."}, "options": {"type": "array", "description": "A list of valid options for the property. This field is required for enumerated properties.", "items": {"required": ["hidden", "label", "value"], "type": "object", "properties": {"hidden": {"type": "boolean", "description": "If true, the option will not be shown in forms, bots, or meeting scheduling pages. Supported for contact, company, ticket, and custom object enumeration properties."}, "displayOrder": {"type": "integer", "description": "Options are shown in order starting with the lowest positive integer value. Values of -1 will cause the option to be displayed after any positive values.", "format": "int32"}, "description": {"type": "string", "description": "A description of the option."}, "label": {"type": "string", "description": "A human-readable option label that will be shown in HubSpot."}, "value": {"type": "string", "description": "The internal value of the option, which must be used when setting the property value through the API."}}, "example": {"description": "Choice number one", "displayOrder": 1, "hidden": false, "label": "Option A", "value": "A"}}}, "calculationFormula": {"type": "string", "description": "Represents a formula that is used to compute a calculated property."}, "hasUniqueValue": {"type": "boolean", "description": "Whether or not the property\'s value must be unique. Once set, this can\'t be changed."}, "fieldType": {"type": "string", "description": "Controls how the property appears in HubSpot.", "enum": ["booleancheckbox", "calculation_equation", "checkbox", "date", "file", "html", "number", "phonenumber", "radio", "select", "text", "textarea"]}, "externalOptions": {"type": "boolean", "description": "Applicable only for \'enumeration\' type properties.  Should be set to true in conjunction with a \'referencedObjectType\' of \'OWNER\'.  Otherwise false."}}, "example": {"displayOrder": 2, "fieldType": "select", "formField": true, "groupName": "contactinformation", "hasUniqueValue": false, "hidden": false, "label": "My Contact Property", "name": "my_contact_property", "options": [{"description": "Choice number one", "displayOrder": 1, "hidden": false, "label": "Option A", "value": "A"}, {"description": "Choice number two", "displayOrder": 2, "hidden": false, "label": "Option B", "value": "B"}], "type": "enumeration"}}}}}',  # noqa: E501
    "CREATEHUBSPOTCRMPROPERTY": '{"required": ["fieldType", "groupName", "label", "name", "type"], "type": "object", "properties": {"hidden": {"type": "boolean", "description": "If true, the option will not be shown in forms, bots, or meeting scheduling pages. Supported for contact, company, ticket, and custom object enumeration properties."}, "displayOrder": {"type": "integer", "description": "Properties are displayed in order starting with the lowest positive integer value. Values of -1 will cause the property to be displayed after any positive values.", "format": "int32"}, "description": {"type": "string", "description": "A description of the property that will be shown as help text in HubSpot."}, "label": {"type": "string", "description": "A human-readable property label that will be shown in HubSpot."}, "type": {"type": "string", "description": "The data type of the property.", "enum": ["bool", "date", "datetime", "enumeration", "number", "phone_number", "string"]}, "formField": {"type": "boolean", "description": "Whether or not the property can be used in a HubSpot form."}, "dataSensitivity": {"type": "string", "enum": ["non_sensitive", "sensitive", "highly_sensitive"]}, "groupName": {"type": "string", "description": "The name of the property group the property belongs to."}, "referencedObjectType": {"type": "string", "description": "Should be set to \'OWNER\' when \'externalOptions\' is true, which causes the property to dynamically pull option values from the current HubSpot users."}, "name": {"type": "string", "description": "The internal property name, which must be used when referencing the property via the API."}, "options": {"type": "array", "description": "A list of valid options for the property. This field is required for enumerated properties.", "items": {"required": ["hidden", "label", "value"], "type": "object", "properties": {"hidden": {"type": "boolean", "description": "If true, the option will not be shown in forms, bots, or meeting scheduling pages. Supported for contact, company, ticket, and custom object enumeration properties."}, "displayOrder": {"type": "integer", "description": "Options are shown in order starting with the lowest positive integer value. Values of -1 will cause the option to be displayed after any positive values.", "format": "int32"}, "description": {"type": "string", "description": "A description of the option."}, "label": {"type": "string", "description": "A human-readable option label that will be shown in HubSpot."}, "value": {"type": "string", "description": "The internal value of the option, which must be used when setting the property value through the API."}}, "example": {"description": "Choice number one", "displayOrder": 1, "hidden": false, "label": "Option A", "value": "A"}}}, "calculationFormula": {"type": "string", "description": "Represents a formula that is used to compute a calculated property."}, "hasUniqueValue": {"type": "boolean", "description": "Whether or not the property\'s value must be unique. Once set, this can\'t be changed."}, "fieldType": {"type": "string", "description": "Controls how the property appears in HubSpot.", "enum": ["booleancheckbox", "calculation_equation", "checkbox", "date", "file", "html", "number", "phonenumber", "radio", "select", "text", "textarea"]}, "externalOptions": {"type": "boolean", "description": "Applicable only for \'enumeration\' type properties.  Should be set to true in conjunction with a \'referencedObjectType\' of \'OWNER\'.  Otherwise false."}}, "example": {"displayOrder": 2, "fieldType": "select", "formField": true, "groupName": "contactinformation", "hasUniqueValue": false, "hidden": false, "label": "My Contact Property", "name": "my_contact_property", "options": [{"description": "Choice number one", "displayOrder": 1, "hidden": false, "label": "Option A", "value": "A"}, {"description": "Choice number two", "displayOrder": 2, "hidden": false, "label": "Option B", "value": "B"}], "type": "enumeration"}}',  # noqa: E501
    "ARCHIVEQUOTESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "CREATEHUBSPOTQUOTE": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "UPDATEQUOTEINFORMATION": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPDATEQUOTEBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATEORUPDATEQUOTES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "CREATEBATCHOFQUOTES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "SEARCHQUOTESINHUBSPOT": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "RETRIEVEQUOTESBATCH": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATECRMOBJECTSCHEMA": '{"required": ["associatedObjects", "labels", "name", "properties", "requiredProperties"], "type": "object", "properties": {"secondaryDisplayProperties": {"type": "array", "description": "The names of secondary properties for this object. These will be displayed as secondary on the HubSpot record page for this object type.", "items": {"type": "string"}}, "requiredProperties": {"type": "array", "description": "The names of properties that should be **required** when creating an object of this type.", "items": {"type": "string"}}, "searchableProperties": {"type": "array", "description": "Names of properties that will be indexed for this object type in by HubSpot\'s product search.", "items": {"type": "string"}}, "primaryDisplayProperty": {"type": "string", "description": "The name of the primary property for this object. This will be displayed as primary on the HubSpot record page for this object type."}, "name": {"type": "string", "description": "A unique name for this object. For internal use only."}, "description": {"type": "string"}, "associatedObjects": {"type": "array", "description": "Associations defined for this object type.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "Properties defined for this object type.", "items": {"required": ["fieldType", "label", "name", "type"], "type": "object", "properties": {"hidden": {"type": "boolean"}, "optionSortStrategy": {"type": "string", "description": "Controls how the property options will be sorted in the HubSpot UI.", "enum": ["DISPLAY_ORDER", "ALPHABETICAL"]}, "displayOrder": {"type": "integer", "description": "The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed **after** any positive values.", "format": "int32"}, "description": {"type": "string", "description": "A description of the property that will be shown as help text in HubSpot."}, "showCurrencySymbol": {"type": "boolean", "description": "Whether the property will display the currency symbol in the HubSpot UI."}, "label": {"type": "string", "description": "A human-readable property label that will be shown in HubSpot."}, "type": {"type": "string", "description": "The data type of the property.", "enum": ["string", "number", "date", "datetime", "enumeration", "bool"]}, "formField": {"type": "boolean", "description": "Whether the property can be used in a HubSpot form."}, "groupName": {"type": "string", "description": "The name of the group this property belongs to."}, "referencedObjectType": {"type": "string", "description": "Defines the options this property will return, e.g. OWNER would return name of users on the portal."}, "textDisplayHint": {"type": "string", "description": "Controls how text properties are formatted in the HubSpot UI", "enum": ["unformatted_single_line", "multi_line", "email", "phone_number", "domain_name", "ip_address", "physical_address", "postal_code"]}, "name": {"type": "string", "description": "The internal property name, which must be used when referencing the property from the API."}, "options": {"type": "array", "description": "A list of available options for the property. This field is only required for enumerated properties.", "items": {"required": ["hidden", "label", "value"], "type": "object", "properties": {"hidden": {"type": "boolean", "description": "If true, the option will not be shown in forms, bots, or meeting scheduling pages. Supported for contact, company, ticket, and custom object enumeration properties."}, "displayOrder": {"type": "integer", "description": "Options are shown in order starting with the lowest positive integer value. Values of -1 will cause the option to be displayed after any positive values.", "format": "int32"}, "description": {"type": "string", "description": "A description of the option."}, "label": {"type": "string", "description": "A human-readable option label that will be shown in HubSpot."}, "value": {"type": "string", "description": "The internal value of the option, which must be used when setting the property value through the API."}}, "example": {"description": "Choice number one", "displayOrder": 1, "hidden": false, "label": "Option A", "value": "A"}}}, "searchableInGlobalSearch": {"type": "boolean", "description": "Allow users to search for information entered to this field (limited to 3 properties)"}, "numberDisplayHint": {"type": "string", "description": "Controls how numeric properties are formatted in the HubSpot UI", "enum": ["unformatted", "formatted", "currency", "percentage", "duration", "probability"]}, "hasUniqueValue": {"type": "boolean", "description": "Whether or not the property\'s value must be unique. Once set, this can\'t be changed."}, "fieldType": {"type": "string", "description": "Controls how the property appears in HubSpot."}}, "description": "Defines a property to create.", "example": {"label": "My object property", "type": "enumeration", "fieldType": "select", "groupName": "my_object_information", "displayOrder": 2, "hasUniqueValue": false, "options": [{"label": "Option A", "description": "Choice number one", "value": "A", "displayOrder": 1}, {"label": "Option B", "description": "Choice number two", "value": "B", "displayOrder": 2}]}}}, "labels": {"type": "object", "properties": {"plural": {"type": "string", "description": "The word for multiple objects. (There\u2019s no way to change this later.)"}, "singular": {"type": "string", "description": "The word for one object. (There\u2019s no way to change this later.)"}}, "description": "Singular and plural labels for the object. Used in CRM display.", "example": {"singular": "My object", "plural": "My objects"}}}, "description": "Defines a new object type, its properties, and associations.", "example": {"name": "my_object", "labels": {"singular": "My object", "plural": "My objects"}, "primaryDisplayProperty": "my_object_property", "requiredProperties": ["my_object_property"], "properties": [{"name": "my_object_property", "label": "My object property", "isPrimaryDisplayLabel": true}], "associatedObjects": ["CONTACT"], "metaType": "PORTAL_SPECIFIC"}}',  # noqa: E501
    "FETCHHUBSPOTOBJECTRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPDATESERVICESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "HUBSPOTCRMUPSERTRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "HUBSPOTSEARCHCUSTOMOBJECTS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "ARCHIVESERVICESBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "EDITHUBSPOTOBJECT": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "CREATESERVICERECORD": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "CREATEBATCHOFSERVICES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "ARCHIVEHUBSPOTTASKS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATEHUBSPOTTASK": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "CREATEBATCHTASKS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPDATEBATCHTASKS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "RETRIEVEHUBSPOTTASKS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPSERTHUBSPOTTASKS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "SEARCHHUBSPOTTASKS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "CREATETASKINCRM": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "CREATEHUBSPOTTAX": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "UPDATETAXOBJECT": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "CREATEORUPDATETAXRECORDS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "UPDATEBATCHTAXES": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "RETRIEVETAXRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATETAXBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "SEARCHTAXES": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "ARCHIVETAXBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "DELETEHUBSPOTTICKETSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "UPDATETICKETINFO": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPSERTCRMTICKETS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "RETRIEVETICKETBATCH": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "CREATETICKET": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
    "SEARCHTICKETS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "CREATEBATCHTICKETS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "UPDATETICKETBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "SENDEVENTTOHUBSPOT": '{"required": ["eventTemplateId", "tokens"], "type": "object", "properties": {"eventTemplateId": {"type": "string", "description": "The event template ID."}, "extraData": {"type": "object", "properties": {}, "description": "Additional event-specific data that can be interpreted by the template\'s markdown."}, "timelineIFrame": {"required": ["headerLabel", "height", "linkLabel", "url", "width"], "type": "object", "properties": {"linkLabel": {"type": "string", "description": "The text displaying the link that will display the iframe."}, "headerLabel": {"type": "string", "description": "The label of the modal window that displays the iframe contents."}, "width": {"type": "integer", "description": "The width of the modal window in pixels.", "format": "int32"}, "url": {"type": "string", "description": "The URI of the iframe contents."}, "height": {"type": "integer", "description": "The height of the modal window in pixels.", "format": "int32"}}, "example": {"linkLabel": "View Art3mis", "headerLabel": "Art3mis dog", "url": "https://my.petspot.com/pets/Art3mis", "width": 600, "height": 400}}, "domain": {"type": "string", "description": "The event domain (often paired with utk)."}, "tokens": {"type": "object", "additionalProperties": {"type": "string"}, "description": "A collection of token keys and values associated with the template tokens."}, "id": {"type": "string", "description": "Identifier for the event. This is optional, and we recommend you do not pass this in. We will create one for you if you omit this. You can also use `{{uuid}}` anywhere in the ID to generate a unique string, guaranteeing uniqueness."}, "utk": {"type": "string", "description": "Use the `utk` parameter to associate an event with a contact by `usertoken`. This is recommended if you don\'t know a user\'s email, but have an identifying user token in your cookie."}, "email": {"type": "string", "description": "The email address used for contact-specific events. This can be used to identify existing contacts, create new ones, or change the email for an existing contact (if paired with the `objectId`)."}, "objectId": {"type": "string", "description": "The CRM object identifier. This is required for every event other than contacts (where utk or email can be used)."}, "timestamp": {"type": "string", "description": "The time the event occurred. If not passed in, the curren time will be assumed. This is used to determine where an event is shown on a CRM object\'s timeline.", "format": "date-time"}}, "description": "The state of the timeline event.", "example": {"eventTemplateId": "1001298", "email": "art3mis-pup@petspot.com", "tokens": {"petName": "Art3mis", "petAge": 3, "petColor": "black"}, "extraData": {"questions": [{"question": "Who\'s a good girl?", "answer": "Bark!"}, {"question": "Do you wanna go on a walk?", "answer": "Woof!"}]}, "timelineIFrame": {"linkLabel": "View Art3mis", "headerLabel": "Art3mis dog", "url": "https://my.petspot.com/pets/Art3mis", "width": 600, "height": 400}}}',  # noqa: E501
    "BATCHCREATETIMELINEEVENTS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "description": "A collection of timeline events we want to create.", "items": {"required": ["eventTemplateId", "tokens"], "type": "object", "properties": {"eventTemplateId": {"type": "string", "description": "The event template ID."}, "extraData": {"type": "object", "properties": {}, "description": "Additional event-specific data that can be interpreted by the template\'s markdown."}, "timelineIFrame": {"required": ["headerLabel", "height", "linkLabel", "url", "width"], "type": "object", "properties": {"linkLabel": {"type": "string", "description": "The text displaying the link that will display the iframe."}, "headerLabel": {"type": "string", "description": "The label of the modal window that displays the iframe contents."}, "width": {"type": "integer", "description": "The width of the modal window in pixels.", "format": "int32"}, "url": {"type": "string", "description": "The URI of the iframe contents."}, "height": {"type": "integer", "description": "The height of the modal window in pixels.", "format": "int32"}}, "example": {"linkLabel": "View Art3mis", "headerLabel": "Art3mis dog", "url": "https://my.petspot.com/pets/Art3mis", "width": 600, "height": 400}}, "domain": {"type": "string", "description": "The event domain (often paired with utk)."}, "tokens": {"type": "object", "additionalProperties": {"type": "string"}, "description": "A collection of token keys and values associated with the template tokens."}, "id": {"type": "string", "description": "Identifier for the event. This is optional, and we recommend you do not pass this in. We will create one for you if you omit this. You can also use `{{uuid}}` anywhere in the ID to generate a unique string, guaranteeing uniqueness."}, "utk": {"type": "string", "description": "Use the `utk` parameter to associate an event with a contact by `usertoken`. This is recommended if you don\'t know a user\'s email, but have an identifying user token in your cookie."}, "email": {"type": "string", "description": "The email address used for contact-specific events. This can be used to identify existing contacts, create new ones, or change the email for an existing contact (if paired with the `objectId`)."}, "objectId": {"type": "string", "description": "The CRM object identifier. This is required for every event other than contacts (where utk or email can be used)."}, "timestamp": {"type": "string", "description": "The time the event occurred. If not passed in, the curren time will be assumed. This is used to determine where an event is shown on a CRM object\'s timeline.", "format": "date-time"}}, "description": "The state of the timeline event.", "example": {"eventTemplateId": "1001298", "email": "art3mis-pup@petspot.com", "tokens": {"petName": "Art3mis", "petAge": 3, "petColor": "black"}, "extraData": {"questions": [{"question": "Who\'s a good girl?", "answer": "Bark!"}, {"question": "Do you wanna go on a walk?", "answer": "Woof!"}]}, "timelineIFrame": {"linkLabel": "View Art3mis", "headerLabel": "Art3mis dog", "url": "https://my.petspot.com/pets/Art3mis", "width": 600, "height": 400}}}}}, "description": "Used to create timeline events in batches.", "example": {"inputs": [{"eventTemplateId": "1001298", "email": "art3mis-pup@petspot.com", "tokens": {"petName": "Art3mis", "petAge": 3, "petColor": "black"}, "extraData": {"questions": [{"question": "Who\'s a good girl?", "answer": "Bark!"}, {"question": "Do you wanna go on a walk?", "answer": "Woof!"}]}, "timelineIFrame": {"linkLabel": "View Art3mis", "headerLabel": "Art3mis dog", "url": "https://my.petspot.com/pets/Art3mis", "width": 600, "height": 400}}, {"eventTemplateId": "1001298", "email": "pocket-tiger@petspot.com", "tokens": {"petName": "Pocket", "petAge": 3, "petColor": "yellow"}, "extraData": {"questions": [{"question": "Who\'s a good kitty?", "answer": "Purr..."}, {"question": "Will you stop playing with that?", "answer": "Meow!"}]}, "timelineIFrame": {"linkLabel": "View Pocket", "headerLabel": "Pocket Tiger", "url": "https://my.petspot.com/pets/Pocket", "width": 600, "height": 400}}]}}',  # noqa: E501
    "UPLOADCALLTRANSCRIPTS": '{"required": ["engagementId", "transcriptCreateUtterances"], "type": "object", "properties": {"transcriptCreateUtterances": {"type": "array", "items": {"required": ["endTimeMillis", "speaker", "startTimeMillis", "text"], "type": "object", "properties": {"endTimeMillis": {"type": "integer", "format": "int32"}, "startTimeMillis": {"type": "integer", "format": "int32"}, "speaker": {"required": ["id", "name"], "type": "object", "properties": {"name": {"type": "string"}, "id": {"type": "string"}, "email": {"type": "string"}}}, "text": {"type": "string"}, "languageCode": {"type": "string"}}}}, "engagementId": {"type": "integer", "format": "int64"}}}',  # noqa: E501
    "SEARCHCRMUSERS": '{"type": "object", "properties": {"query": {"type": "string", "description": "The search query string, up to 3000 characters."}, "limit": {"type": "integer", "description": "The maximum results to return, up to 200 objects.", "format": "int32"}, "after": {"type": "string", "description": "A paging cursor token for retrieving subsequent pages."}, "sorts": {"type": "array", "description": "Specifies sorting order based on object properties.", "items": {"type": "string"}}, "properties": {"type": "array", "description": "A list of property names to include in the response.", "items": {"type": "string"}}, "filterGroups": {"type": "array", "description": "Up to 6 groups of filters defining additional query criteria.", "items": {"required": ["filters"], "type": "object", "properties": {"filters": {"type": "array", "items": {"required": ["operator", "propertyName"], "type": "object", "properties": {"highValue": {"type": "string", "description": "The upper boundary value when using ranged-based filters."}, "propertyName": {"type": "string", "description": "The name of the property to apply the filter to."}, "values": {"type": "array", "description": "The values to match against the property.", "items": {"type": "string"}}, "value": {"type": "string", "description": "The value to match against the property."}, "operator": {"type": "string", "description": "null", "enum": ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]}}, "description": "Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against. "}}}}}}, "description": "Describes a search request"}',  # noqa: E501
    "CREATEUSERSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["associations", "properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "objectWriteTraceId": {"type": "string"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}}}}}}}',  # noqa: E501
    "ARCHIVEUSERSBATCH": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}',  # noqa: E501
    "RETRIEVEHUBSPOTUSERRECORDS": '{"required": ["inputs", "properties", "propertiesWithHistory"], "type": "object", "properties": {"propertiesWithHistory": {"type": "array", "description": "Key-value pairs for setting properties for the new object and their histories.", "items": {"type": "string"}}, "idProperty": {"type": "string", "description": "When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID."}, "inputs": {"type": "array", "items": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}, "properties": {"type": "array", "description": "Key-value pairs for setting properties for the new object.", "items": {"type": "string"}}}, "description": "Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property."}',  # noqa: E501
    "UPSERTHUBSPOTUSERS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object"}, "objectWriteTraceId": {"type": "string", "description": "An identifier for tracing the creation request."}, "id": {"type": "string", "description": "The unique ID of the object."}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents an object used in batch upsert operations, containing an object\u2019s unique identifier, its properties, and optionally the unique property name and a write trace ID."}}}}',  # noqa: E501
    "UPDATEHUBSPOTUSER": '{"required": ["properties"], "type": "object", "properties": {"properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key value pairs representing the properties of the object."}}, "description": "Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.", "example": {"properties": {"property_checkbox": "false", "property_date": "1572480000000", "property_dropdown": "choice_b", "property_multiple_checkboxes": "chocolate;strawberry", "property_number": "17", "property_radio": "option_1", "property_string": "value"}}}',  # noqa: E501
    "UPDATEMULTIPLEUSERS": '{"required": ["inputs"], "type": "object", "properties": {"inputs": {"type": "array", "items": {"required": ["id", "properties"], "type": "object", "properties": {"idProperty": {"type": "string", "description": "The name of a property whose values are unique for this object", "example": "my_unique_property_name"}, "objectWriteTraceId": {"type": "string", "description": "A unique identifier for tracing the request."}, "id": {"type": "string", "description": "The id to be updated. This can be the object id, or the unique property value of the idProperty property"}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs representing the properties of the object."}}, "description": "Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties."}}}}',  # noqa: E501
    "CREATECRMUSER": '{"required": ["properties"], "type": "object", "properties": {"associations": {"type": "array", "items": {"required": ["to", "types"], "type": "object", "properties": {"types": {"type": "array", "items": {"required": ["associationCategory", "associationTypeId"], "type": "object", "properties": {"associationCategory": {"type": "string", "description": "The category of the association, such as "HUBSPOT_DEFINED".", "enum": ["HUBSPOT_DEFINED", "USER_DEFINED", "INTEGRATOR_DEFINED"]}, "associationTypeId": {"type": "integer", "description": "The ID representing the specific type of association.", "format": "int32"}}, "description": "Defines the type, direction, and details of the relationship between two CRM objects."}}, "to": {"required": ["id"], "type": "object", "properties": {"id": {"type": "string"}}}}}}, "properties": {"type": "object", "additionalProperties": {"type": "string"}, "description": "Key-value pairs for setting properties for the new object."}}, "description": "Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects."}',  # noqa: E501
}
